@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -49,10 +49,18 @@ from blinker import signal
 from . import __version__
 from .plugin_categories import Command
 from .nikola import Nikola
-from .utils import _reload, sys_decode, get_root_dir, req_missing, LOGGER, STRICT_HANDLER, ColorfulStderrHandler
+from .utils import sys_decode, get_root_dir, req_missing, LOGGER, STRICT_HANDLER, ColorfulStderrHandler
+
+if sys.version_info[0] == 3:
+    import importlib.machinery
+else:
+    import imp
 
 config = {}
 
+# DO NOT USE unless you know what you are doing!
+_RETURN_DOITNIKOLA = False
+
 
 def main(args=None):
     colorful = False
@@ -63,6 +71,16 @@ def main(args=None):
 
     if args is None:
         args = sys.argv[1:]
+
+    conf_filename = 'conf.py'
+    conf_filename_changed = False
+    for index, arg in enumerate(args):
+        if arg[:7] == '--conf=':
+            del args[index]
+            conf_filename = arg[7:]
+            conf_filename_changed = True
+            break
+
     quiet = False
     if len(args) > 0 and args[0] == b'build' and b'--strict' in args:
         LOGGER.notice('Running in strict mode')
@@ -82,19 +100,32 @@ def main(args=None):
         root = get_root_dir()
         if root:
             os.chdir(root)
+        # help does not need a config file, but can use one.
+        needs_config_file = argname != 'help'
+    else:
+        needs_config_file = False
 
     sys.path.append('')
     try:
-        import conf
-        _reload(conf)
+        if sys.version_info[0] == 3:
+            loader = importlib.machinery.SourceFileLoader("conf", conf_filename)
+            conf = loader.load_module()
+        else:
+            conf = imp.load_source("conf", conf_filename)
         config = conf.__dict__
     except Exception:
-        if os.path.exists('conf.py'):
+        if os.path.exists(conf_filename):
             msg = traceback.format_exc(0)
-            LOGGER.error('conf.py cannot be parsed.\n{0}'.format(msg))
+            LOGGER.error('"{0}" cannot be parsed.\n{1}'.format(conf_filename, msg))
+            sys.exit(1)
+        elif needs_config_file and conf_filename_changed:
+            LOGGER.error('Cannot find configuration file "{0}".'.format(conf_filename))
             sys.exit(1)
         config = {}
 
+    if conf_filename_changed:
+        LOGGER.info("Using config file '{0}'".format(conf_filename))
+
     invariant = False
 
     if len(args) > 0 and args[0] == b'build' and b'--invariant' in args:
@@ -114,9 +145,13 @@ def main(args=None):
     config['__colorful__'] = colorful
     config['__invariant__'] = invariant
     config['__quiet__'] = quiet
+    config['__configuration_filename__'] = conf_filename
 
     site = Nikola(**config)
-    _ = DoitNikola(site, quiet).run(args)
+    DN = DoitNikola(site, quiet)
+    if _RETURN_DOITNIKOLA:
+        return DN
+    _ = DN.run(args)
 
     if site.invariant:
         freeze.stop()
@@ -219,7 +254,7 @@ class NikolaTaskLoader(TaskLoader):
             self.nikola.gen_tasks('render_site', "Task", 'Group of tasks to render the site.'))
         latetasks = generate_tasks(
             'post_render',
-            self.nikola.gen_tasks('post_render', "LateTask", 'Group of tasks to be executes after site is rendered.'))
+            self.nikola.gen_tasks('post_render', "LateTask", 'Group of tasks to be executed after site is rendered.'))
         signal('initialized').send(self.nikola)
         return tasks + latetasks, DOIT_CONFIG
 
