@@ -2,27 +2,31 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Dostupné také v",
+    "%d min remaining to read": "%d min zbývajících",
     "Also available in:": "Dostupné také v",
     "Archive": "Archiv",
     "Categories": "Kategorie",
+    "Comments": "Komentáře",
     "LANGUAGE": "Čeština",
+    "Languages:": "Jazyky:",
     "More posts about %s": "Další příspěvky o %s",
-    "More posts about": "Další příspěvky o",
     "Newer posts": "Novější příspěvky",
     "Next post": "Další příspěvek",
-    "No posts found.": "",
-    "Nothing found.": "",
+    "No posts found.": "Nebyly nalezeny žádné příspěvky.",
+    "Nothing found.": "Nic nebylo nalezeno.",
     "Older posts": "Starší příspěvky",
     "Original site": "Původní stránka",
-    "Posted": "Zveřejněno",
     "Posted:": "Zveřejněno:",
     "Posts about %s": "Příspěvky o %s",
     "Posts for year %s": "Příspěvky v roce %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Příspěvky v {month} {year}",
     "Previous post": "Předchozí příspěvek",
+    "Publication date": "Datum zveřejnění",
+    "RSS feed": "RSS zdroj",
     "Read in English": "Číst v češtině",
     "Read more": "Číst dál",
+    "Skip to main content": "Přeskočit na hlavní obsah",
     "Source": "Zdroj",
     "Tags and Categories": "Štítky a kategorie",
     "Tags": "Štítky",
