@@ -19,13 +19,14 @@ MESSAGES = {
     "Posted:": "Veröffentlicht:",
     "Posts about %s": "Einträge über %s",
     "Posts for year %s": "Einträge aus dem Jahr %s",
+    "Posts for {month} {day}, {year}": "Einträge vom {day}. {month} {year}",
     "Posts for {month} {year}": "Einträge aus {month} {year}",
     "Previous post": "Vorheriger Eintrag",
     "Publication date": "Veröffentlichungsdatum",
     "RSS feed": "RSS-Feed",
     "Read in English": "Auf Deutsch lesen",
     "Read more": "Weiterlesen",
-    "Skip to main content": "",
+    "Skip to main content": "Springe zum Hauptinhalt",
     "Source": "Source",
     "Tags and Categories": "Tags und Kategorien",
     "Tags": "Tags",
