@@ -2,27 +2,31 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Διαθέσιμο και στα",
+    "%d min remaining to read": "",
     "Also available in:": "Διαθέσιμο και στα:",
     "Archive": "Αρχείο",
     "Categories": "Κατηγορίες",
+    "Comments": "",
     "LANGUAGE": "Ελληνικά",
+    "Languages:": "",
     "More posts about %s": "Περισσότερες αναρτήσεις για %s",
-    "More posts about": "Περισσότερες αναρτήσεις για",
     "Newer posts": "Νεότερες αναρτήσεις",
     "Next post": "Επόμενη ανάρτηση",
     "No posts found.": "",
     "Nothing found.": "",
     "Older posts": "Παλαιότερες αναρτήσεις",
     "Original site": "Ιστοσελίδα αρχικής ανάρτησης",
-    "Posted": "Αναρτήθηκε",
     "Posted:": "Αναρτήθηκε:",
     "Posts about %s": "Αναρτήσεις για %s",
     "Posts for year %s": "Αναρτήσεις για το έτος %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Αναρτήσεις για τον {month} του {year}",
     "Previous post": "Προηγούμενη ανάρτηση",
+    "Publication date": "",
+    "RSS feed": "",
     "Read in English": "Διαβάστε στα Ελληνικά",
     "Read more": "Διαβάστε περισσότερα",
+    "Skip to main content": "",
     "Source": "Πηγαίος κώδικας",
     "Tags and Categories": "Ετικέτες και κατηγορίες",
     "Tags": "Ετικέτες",
