@@ -2,27 +2,31 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Also available in",
+    "%d min remaining to read": "%d min remaining to read",
     "Also available in:": "Also available in:",
     "Archive": "Archive",
     "Categories": "Categories",
+    "Comments": "Comments",
     "LANGUAGE": "English",
+    "Languages:": "Languages:",
     "More posts about %s": "More posts about %s",
-    "More posts about": "More posts about",
     "Newer posts": "Newer posts",
     "Next post": "Next post",
     "No posts found.": "No posts found.",
     "Nothing found.": "Nothing found.",
     "Older posts": "Older posts",
     "Original site": "Original site",
-    "Posted": "Posted",
     "Posted:": "Posted:",
     "Posts about %s": "Posts about %s",
     "Posts for year %s": "Posts for year %s",
+    "Posts for {month} {day}, {year}": "Posts for {month} {day}, {year}",
     "Posts for {month} {year}": "Posts for {month} {year}",
     "Previous post": "Previous post",
+    "Publication date": "Publication date",
+    "RSS feed": "RSS feed",
     "Read in English": "Read in English",
     "Read more": "Read more",
+    "Skip to main content": "Skip to main content",
     "Source": "Source",
     "Tags and Categories": "Tags and Categories",
     "Tags": "Tags",
