@@ -2,27 +2,31 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Saadaval ka",
+    "%d min remaining to read": "",
     "Also available in:": "Saadaval ka:",
     "Archive": "Arhiiv",
     "Categories": "Kategooriad",
+    "Comments": "",
     "LANGUAGE": "Eesti",
+    "Languages:": "",
     "More posts about %s": "Veel postitusi %s kohta",
-    "More posts about": "Veel postitusi kohta",
     "Newer posts": "Uued postitused",
     "Next post": "Järgmine postitus",
     "No posts found.": "",
     "Nothing found.": "",
     "Older posts": "Vanemad postitused",
     "Original site": "Algallikas",
-    "Posted": "Postitatud",
     "Posted:": "Postitatud:",
     "Posts about %s": "Postitused %s kohta",
     "Posts for year %s": "Postitused aastast %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Postitused {year} aasta kuust {month} ",
     "Previous post": "Eelmine postitus",
+    "Publication date": "",
+    "RSS feed": "",
     "Read in English": "Loe eesti keeles",
     "Read more": "Loe veel",
+    "Skip to main content": "",
     "Source": "Lähtekood",
     "Tags and Categories": "Sildid ja kategooriad",
     "Tags": "Märksõnad",
