@@ -2,7 +2,7 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "%d min remaining to read": "",
+    "%d min remaining to read": "%d minuuttia lukuaikaa",
     "Also available in:": "Saatavilla myös:",
     "Archive": "Arkisto",
     "Categories": "Kategoriat",
@@ -19,13 +19,14 @@ MESSAGES = {
     "Posted:": "Postattu:",
     "Posts about %s": "Postauksia aiheesta %s",
     "Posts for year %s": "Postauksia vuodelta %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Postauksia ajalle {month} {year}",
     "Previous post": "Vanhempia postauksia",
     "Publication date": "Julkaisupäivämäärä",
     "RSS feed": "RSS syöte",
     "Read in English": "Lue suomeksi",
     "Read more": "Lue lisää",
-    "Skip to main content": "",
+    "Skip to main content": "Hyppää sisältöön",
     "Source": "Lähde",
     "Tags and Categories": "Tagit ja kategoriat",
     "Tags": "Tagit",
