@@ -19,12 +19,14 @@ MESSAGES = {
     "Posted:": "Objavljeno:",
     "Posts about %s": "Postovi o %s",
     "Posts for year %s": "Postovi za godinu %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Postovi za {month} {year}",
     "Previous post": "Prethodni post",
     "Publication date": "Nadnevak objave",
     "RSS feed": "RSS kanal",
     "Read in English": "Čitaj na hrvatskom",
     "Read more": "Čitaj dalje",
+    "Skip to main content": "",
     "Source": "Izvor",
     "Tags and Categories": "Tagovi i kategorije",
     "Tags": "Tagovi",
