@@ -2,27 +2,31 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Anche disponibile in",
+    "%d min remaining to read": "ancora %d minuti",
     "Also available in:": "Anche disponibile in:",
     "Archive": "Archivio",
     "Categories": "Categorie",
+    "Comments": "Commenti",
     "LANGUAGE": "Italiano",
+    "Languages:": "Lingue:",
     "More posts about %s": "Altri articoli collegati %s",
-    "More posts about": "Altri articoli collegati",
     "Newer posts": "Articoli recenti",
     "Next post": "Articolo successivo",
-    "No posts found.": "",
-    "Nothing found.": "",
+    "No posts found.": "Nessun articolo trovato.",
+    "Nothing found.": "Non trovato.",
     "Older posts": "Articoli precedenti",
     "Original site": "Sito originale",
-    "Posted": "Pubblicato",
     "Posted:": "Pubblicato:",
     "Posts about %s": "Articoli su %s",
     "Posts for year %s": "Articoli per l'anno %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Articoli per {month} {year}",
     "Previous post": "Articolo precedente",
+    "Publication date": "Data di pubblicazione",
+    "RSS feed": "Flusso RSS",
     "Read in English": "Leggi in italiano",
-    "Read more": "Espandi",
+    "Read more": "Continua la lettura",
+    "Skip to main content": "",
     "Source": "Sorgente",
     "Tags and Categories": "Tags e Categorie",
     "Tags": "Tags",
