@@ -2,30 +2,34 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "他の言語で読む",
+    "%d min remaining to read": "",
     "Also available in:": "他の言語で読む：",
     "Archive": "過去の記事",
     "Categories": "カテゴリー",
+    "Comments": "コメント",
     "LANGUAGE": "日本語",
+    "Languages:": "言語 :",
     "More posts about %s": "タグ： %s",
-    "More posts about": "タグ：",
     "Newer posts": "新しい記事",
     "Next post": "次の記事",
-    "No posts found.": "",
-    "Nothing found.": "",
+    "No posts found.": "記事はありません",
+    "Nothing found.": "なにも見つかりませんでした",
     "Older posts": "過去の記事",
     "Original site": "元のサイト",
-    "Posted": "投稿日時",
     "Posted:": "投稿日時：",
     "Posts about %s": "%sについての記事",
     "Posts for year %s": "%s年の記事",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "{year}年{month}月の記事",
     "Previous post": "前の記事",
+    "Publication date": "投稿日",
+    "RSS feed": "RSS フィード",
     "Read in English": "日本語で読む",
     "Read more": "続きを読む",
+    "Skip to main content": "",
     "Source": "ソース",
     "Tags and Categories": "タグとカテゴリー",
     "Tags": "タグ",
     "old posts, page %d": "前の記事 %dページ目",
-    "page %d": "",
+    "page %d": "ページ %d",
 }
