@@ -19,12 +19,14 @@ MESSAGES = {
     "Posted:": "Geplaatst:",
     "Posts about %s": "Berichten over %s",
     "Posts for year %s": "Berichten voor het jaar %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Berichten voor {month} {year}",
     "Previous post": "Vorig bericht",
     "Publication date": "Publicatiedatum",
     "RSS feed": "RSS-feed",
     "Read in English": "Lees in het Nederlands",
     "Read more": "Lees verder",
+    "Skip to main content": "Ga door naar de hoofdinhoud",
     "Source": "Bron",
     "Tags and Categories": "Tags en Categorieën",
     "Tags": "Tags",
