@@ -2,30 +2,34 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Również dostępny w językach",
+    "%d min remaining to read": "zostało %d minut czytania",
     "Also available in:": "Również dostępny w językach:",
     "Archive": "Archiwum",
     "Categories": "Kategorie",
-    "LANGUAGE": "polski",
+    "Comments": "Komentarze",
+    "LANGUAGE": "Polski",
+    "Languages:": "Języki:",
     "More posts about %s": "Więcej postów o %s",
-    "More posts about": "Więcej postów o",
     "Newer posts": "Nowsze posty",
     "Next post": "Następny post",
     "No posts found.": "Nie znaleziono żadnych postów.",
     "Nothing found.": "Nic nie znaleziono.",
     "Older posts": "Starsze posty",
     "Original site": "Oryginalna strona",
-    "Posted": "Opublikowano",
     "Posted:": "Opublikowano:",
     "Posts about %s": "Posty o %s",
     "Posts for year %s": "Posty z roku %s",
+    "Posts for {month} {day}, {year}": "Posty z {day} {month} {year}",
     "Posts for {month} {year}": "Posty z {month} {year}",
     "Previous post": "Poprzedni post",
+    "Publication date": "Data publikacji",
+    "RSS feed": "Kanał RSS",
     "Read in English": "Czytaj po polsku",
     "Read more": "Czytaj więcej",
+    "Skip to main content": "Przejdź do treści",
     "Source": "Źródło",
     "Tags and Categories": "Tagi i Kategorie",
-    "Tags": "Tags",
+    "Tags": "Tagi",
     "old posts, page %d": "stare posty, strona %d",
     "page %d": "strona %d",
 }
