@@ -2,29 +2,31 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "%d min remaining to read": "",
+    "%d min remaining to read": "%d минут чтения осталось",
     "Also available in:": "Также доступно на:",
     "Archive": "Архив",
     "Categories": "Категории",
-    "Comments": "",
+    "Comments": "Комментарии",
     "LANGUAGE": "Русский",
-    "Languages:": "",
+    "Languages:": "Языки:",
     "More posts about %s": "Больше записей о %s",
     "Newer posts": "Новые записи",
     "Next post": "Следующая запись",
-    "No posts found.": "",
-    "Nothing found.": "",
+    "No posts found.": "Записей не найдено.",
+    "Nothing found.": "Ничего не найдено.",
     "Older posts": "Старые записи",
     "Original site": "Оригинальный сайт",
     "Posted:": "Опубликовано:",
     "Posts about %s": "Записи о %s",
     "Posts for year %s": "Записи за %s год",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Записи за {month} {year}",
     "Previous post": "Предыдущая запись",
-    "Publication date": "",
-    "RSS feed": "",
+    "Publication date": "Дата опубликования",
+    "RSS feed": "RSS лента",
     "Read in English": "Прочесть по-русски",
     "Read more": "Читать далее",
+    "Skip to main content": "Перейти к главному содержимому",
     "Source": "Источник",
     "Tags and Categories": "Тэги и категории",
     "Tags": "Тэги",
