@@ -2,27 +2,31 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Na voljo tudi v",
+    "%d min remaining to read": "še %d min za branje preostanka",
     "Also available in:": "Na voljo tudi v:",
     "Archive": "Arhiv",
     "Categories": "Kategorije",
+    "Comments": "Komentarji",
     "LANGUAGE": "Slovenščina",
+    "Languages:": "Jeziki:",
     "More posts about %s": "Več objav o %s",
-    "More posts about": "Več objav o",
     "Newer posts": "Novejše objave",
     "Next post": "Naslednja objava",
-    "No posts found.": "",
-    "Nothing found.": "",
+    "No posts found.": "Ni najdenih objav.",
+    "Nothing found.": "Brez zadetkov.",
     "Older posts": "Starejše objave",
     "Original site": "Izvorna spletna stran",
-    "Posted": "Objavljeno",
     "Posted:": "Objavljeno:",
     "Posts about %s": "Objave o %s",
     "Posts for year %s": "Objave za leto %s",
+    "Posts for {month} {day}, {year}": "",
     "Posts for {month} {year}": "Objave za {month} {year}",
     "Previous post": "Prejšnja objava",
+    "Publication date": "Datum objave",
+    "RSS feed": "vir RSS",
     "Read in English": "Beri v slovenščini",
     "Read more": "Več o tem",
+    "Skip to main content": "Preskoči na glavno vsebino",
     "Source": "Izvor",
     "Tags and Categories": "Značke in kategorije",
     "Tags": "Značke",
