@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -28,6 +28,7 @@ from __future__ import unicode_literals, print_function
 import os
 import re
 import sys
+import datetime
 from lxml import etree
 
 try:
@@ -51,7 +52,7 @@ from nikola import utils
 from nikola.utils import req_missing
 from nikola.plugins.basic_import import ImportMixin, links
 from nikola.nikola import DEFAULT_TRANSLATIONS_PATTERN
-from nikola.plugins.command.init import SAMPLE_CONF, prepare_config
+from nikola.plugins.command.init import SAMPLE_CONF, prepare_config, format_default_translations_config
 
 LOGGER = utils.get_logger('import_wordpress', utils.STDERR_HANDLER)
 
@@ -136,6 +137,9 @@ class CommandImportWordpress(Command, ImportMixin):
         self.separate_qtranslate_content = options.get('separate_qtranslate_content')
         self.translations_pattern = options.get('translations_pattern')
 
+        # A place holder where extra language (if detected) will be stored
+        self.extra_languages = set()
+
         if not self.no_downloads:
             def show_info_about_mising_module(modulename):
                 LOGGER.error(
@@ -155,6 +159,7 @@ class CommandImportWordpress(Command, ImportMixin):
 
         channel = self.get_channel_from_file(self.wordpress_export_file)
         self.context = self.populate_context(channel)
+        self.base_dir = urlparse(self.context['BASE_URL']).path
         conf_template = self.generate_base_site()
 
         # If user  has specified a custom pattern for translation files we
@@ -164,6 +169,8 @@ class CommandImportWordpress(Command, ImportMixin):
 
         self.import_posts(channel)
 
+        self.context['TRANSLATIONS'] = format_default_translations_config(
+            self.extra_languages)
         self.context['REDIRECTIONS'] = self.configure_redirections(
             self.url_map)
         self.write_urlmap_csv(
@@ -179,26 +186,6 @@ class CommandImportWordpress(Command, ImportMixin):
         self.write_configuration(self.get_configuration_output_path(),
                                  rendered_template)
 
-    @classmethod
-    def _glue_xml_lines(cls, xml):
-        new_xml = xml[0]
-        previous_line_ended_in_newline = new_xml.endswith(b'\n')
-        previous_line_was_indentet = False
-        for line in xml[1:]:
-            if (re.match(b'^[ \t]+', line) and previous_line_ended_in_newline):
-                new_xml = b''.join((new_xml, line))
-                previous_line_was_indentet = True
-            elif previous_line_was_indentet:
-                new_xml = b''.join((new_xml, line))
-                previous_line_was_indentet = False
-            else:
-                new_xml = b'\n'.join((new_xml, line))
-                previous_line_was_indentet = False
-
-            previous_line_ended_in_newline = line.endswith(b'\n')
-
-        return new_xml
-
     @classmethod
     def read_xml_file(cls, filename):
         xml = []
@@ -209,8 +196,7 @@ class CommandImportWordpress(Command, ImportMixin):
                 if b'<atom:link rel=' in line:
                     continue
                 xml.append(line)
-
-        return cls._glue_xml_lines(xml)
+        return b'\n'.join(xml)
 
     @classmethod
     def get_channel_from_file(cls, filename):
@@ -249,9 +235,15 @@ class CommandImportWordpress(Command, ImportMixin):
             '{{{0}}}author_display_name'.format(wordpress_namespace),
             "Joe Example")
         context['POSTS'] = '''(
+            ("posts/*.rst", "posts", "post.tmpl"),
+            ("posts/*.txt", "posts", "post.tmpl"),
+            ("posts/*.md", "posts", "post.tmpl"),
             ("posts/*.wp", "posts", "post.tmpl"),
         )'''
         context['PAGES'] = '''(
+            ("stories/*.rst", "stories", "story.tmpl"),
+            ("stories/*.txt", "stories", "story.tmpl"),
+            ("stories/*.md", "stories", "story.tmpl"),
             ("stories/*.wp", "stories", "story.tmpl"),
         )'''
         context['COMPILERS'] = '''{
@@ -318,15 +310,17 @@ class CommandImportWordpress(Command, ImportMixin):
                 # your blogging into another site or system its not.
                 # Why don't they just use JSON?
                 if sys.version_info[0] == 2:
-                    metadata = phpserialize.loads(utils.sys_encode(meta_value.text))
-                    size_key = 'sizes'
-                    file_key = 'file'
+                    try:
+                        metadata = phpserialize.loads(utils.sys_encode(meta_value.text))
+                    except ValueError:
+                        # local encoding might be wrong sometimes
+                        metadata = phpserialize.loads(meta_value.text.encode('utf-8'))
                 else:
-                    metadata = phpserialize.loads(meta_value.text.encode('UTF-8'))
-                    size_key = b'sizes'
-                    file_key = b'file'
+                    metadata = phpserialize.loads(meta_value.text.encode('utf-8'))
+                size_key = b'sizes'
+                file_key = b'file'
 
-                if not size_key in metadata:
+                if size_key not in metadata:
                     continue
 
                 for filename in [metadata[size_key][size][file_key] for size in metadata[size_key]]:
@@ -380,31 +374,45 @@ class CommandImportWordpress(Command, ImportMixin):
         # link is something like http://foo.com/2012/09/01/hello-world/
         # So, take the path, utils.slugify it, and that's our slug
         link = get_text_tag(item, 'link', None)
-        path = unquote(urlparse(link).path.strip('/'))
+        parsed = urlparse(link)
+        path = unquote(parsed.path.strip('/'))
 
         # In python 2, path is a str. slug requires a unicode
         # object. According to wikipedia, unquoted strings will
         # usually be UTF8
         if isinstance(path, utils.bytes_str):
             path = path.decode('utf8')
+
+        # Cut out the base directory.
+        if path.startswith(self.base_dir.strip('/')):
+            path = path.replace(self.base_dir.strip('/'), '', 1)
+
         pathlist = path.split('/')
-        if len(pathlist) > 1:
-            out_folder = os.path.join(*([out_folder] + pathlist[:-1]))
-        slug = utils.slugify(pathlist[-1])
-        if not slug:  # it happens if the post has no "nice" URL
+        if parsed.query:  # if there are no nice URLs and query strings are used
+            out_folder = os.path.join(*([out_folder] + pathlist))
             slug = get_text_tag(
                 item, '{{{0}}}post_name'.format(wordpress_namespace), None)
-        if not slug:  # it *may* happen
-            slug = get_text_tag(
-                item, '{{{0}}}post_id'.format(wordpress_namespace), None)
-        if not slug:  # should never happen
-            LOGGER.error("Error converting post:", title)
-            return
+            if not slug:  # it *may* happen
+                slug = get_text_tag(
+                    item, '{{{0}}}post_id'.format(wordpress_namespace), None)
+            if not slug:  # should never happen
+                LOGGER.error("Error converting post:", title)
+                return
+        else:
+            if len(pathlist) > 1:
+                out_folder = os.path.join(*([out_folder] + pathlist[:-1]))
+            slug = utils.slugify(pathlist[-1])
 
         description = get_text_tag(item, 'description', '')
         post_date = get_text_tag(
             item, '{{{0}}}post_date'.format(wordpress_namespace), None)
-        dt = utils.to_datetime(post_date)
+        try:
+            dt = utils.to_datetime(post_date)
+        except ValueError:
+            dt = datetime.datetime(1970, 1, 1, 0, 0, 0)
+            LOGGER.error('Malformed date "{0}" in "{1}" [{2}], assuming 1970-01-01 00:00:00 instead.'.format(post_date, title, slug))
+            post_date = dt.strftime('%Y-%m-%d %H:%M:%S')
+
         if dt.tzinfo and self.timezone is None:
             self.timezone = utils.get_tzname(dt)
         status = get_text_tag(
@@ -435,8 +443,9 @@ class CommandImportWordpress(Command, ImportMixin):
             LOGGER.notice('Draft "{0}" will not be imported.'.format(title))
         elif content.strip():
             # If no content is found, no files are written.
-            self.url_map[link] = (self.context['SITE_URL'] + out_folder + '/'
-                                  + slug + '.html')
+            self.url_map[link] = (self.context['SITE_URL'] +
+                                  out_folder.rstrip('/') + '/' + slug +
+                                  '.html').replace(os.sep, '/')
             if hasattr(self, "separate_qtranslate_content") \
                and self.separate_qtranslate_content:
                 content_translations = separate_qtranslate_content(content)
@@ -452,6 +461,7 @@ class CommandImportWordpress(Command, ImportMixin):
                         out_content_filename \
                             = utils.get_translation_candidate(self.context,
                                                               slug + ".wp", lang)
+                        self.extra_languages.add(lang)
                     meta_slug = slug
                 else:
                     out_meta_filename = slug + '.meta'
