@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -24,23 +24,24 @@
 # OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 import os
 import shutil
-import codecs
+import io
 import json
 import textwrap
 import datetime
-
+import unidecode
 import dateutil.tz
+import dateutil.zoneinfo
 from mako.template import Template
 from pkg_resources import resource_filename
+import tarfile
 
 import nikola
 from nikola.nikola import DEFAULT_TRANSLATIONS_PATTERN, DEFAULT_INDEX_READ_MORE_LINK, DEFAULT_RSS_READ_MORE_LINK, LEGAL_VALUES
 from nikola.plugin_categories import Command
 from nikola.utils import ask, ask_yesno, get_logger, makedirs, STDERR_HANDLER, load_messages
-from nikola.winutils import fix_git_symlinked
 from nikola.packages.tzlocal import get_localzone
 
 
@@ -237,16 +238,21 @@ class CommandInit(Command):
     def copy_sample_site(cls, target):
         src = resource_filename('nikola', os.path.join('data', 'samplesite'))
         shutil.copytree(src, target)
-        fix_git_symlinked(src, target)
 
-    @classmethod
-    def create_configuration(cls, target):
+    @staticmethod
+    def create_configuration(target):
         template_path = resource_filename('nikola', 'conf.py.in')
         conf_template = Template(filename=template_path)
         conf_path = os.path.join(target, 'conf.py')
-        with codecs.open(conf_path, 'w+', 'utf8') as fd:
+        with io.open(conf_path, 'w+', encoding='utf8') as fd:
             fd.write(conf_template.render(**prepare_config(SAMPLE_CONF)))
 
+    @staticmethod
+    def create_configuration_to_string():
+        template_path = resource_filename('nikola', 'conf.py.in')
+        conf_template = Template(filename=template_path)
+        return conf_template.render(**prepare_config(SAMPLE_CONF))
+
     @classmethod
     def create_empty_site(cls, target):
         for folder in ('files', 'galleries', 'listings', 'posts', 'stories'):
@@ -263,7 +269,11 @@ class CommandInit(Command):
             answer = ask('Language(s) to use', 'en')
             while answer.strip() == '?':
                 print('\n# Available languages:')
-                print(SAMPLE_CONF['_SUPPORTED_LANGUAGES'] + '\n')
+                try:
+                    print(SAMPLE_CONF['_SUPPORTED_LANGUAGES'] + '\n')
+                except UnicodeEncodeError:
+                    # avoid Unicode characters in supported language names
+                    print(unidecode.unidecode(SAMPLE_CONF['_SUPPORTED_LANGUAGES']) + '\n')
                 answer = ask('Language(s) to use', 'en')
 
             langs = [i.strip().lower().replace('-', '_') for i in answer.split(',')]
@@ -295,7 +305,7 @@ class CommandInit(Command):
                 lhandler(default, toconf, show_header=False)
 
         def tzhandler(default, toconf):
-            print("\nPlease choose the correct time zone for your blog.  Nikola uses the tz database.")
+            print("\nPlease choose the correct time zone for your blog. Nikola uses the tz database.")
             print("You can find your time zone here:")
             print("http://en.wikipedia.org/wiki/List_of_tz_database_time_zones")
             print("")
@@ -307,6 +317,18 @@ class CommandInit(Command):
                     lz = None
                 answer = ask('Time zone', lz if lz else "UTC")
                 tz = dateutil.tz.gettz(answer)
+
+                if tz is None:
+                    print("    WARNING: Time zone not found.  Searching most common timezones for a match.")
+                    zonesfile = tarfile.TarFile.open(os.path.join(dateutil.zoneinfo.ZONEINFOFILE))
+                    zonenames = [zone for zone in zonesfile.getnames() if answer.lower() in zone.lower()]
+                    if len(zonenames) == 1:
+                        tz = dateutil.tz.gettz(zonenames[0])
+                    elif len(zonenames) > 1:
+                        print("    Could not pick one timezone. Choose one of the following:")
+                        print('        ' + '\n        '.join(zonenames))
+                        continue
+
                 if tz is not None:
                     time = datetime.datetime.now(tz).strftime('%H:%M:%S')
                     print("    Current time in {0}: {1}".format(answer, time))
