@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2013-2014 Damián Avila and others.
+# Copyright © 2013-2015 Damián Avila and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -27,7 +27,7 @@
 """Implementation of compile_html based on nbconvert."""
 
 from __future__ import unicode_literals, print_function
-import codecs
+import io
 import os
 
 try:
@@ -41,16 +41,13 @@ except ImportError:
 from nikola.plugin_categories import PageCompiler
 from nikola.utils import makedirs, req_missing
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    OrderedDict = dict  # NOQA
-
 
 class CompileIPynb(PageCompiler):
     """Compile IPynb into HTML."""
 
     name = "ipynb"
+    supports_onefile = False
+    demote_headers = True
 
     def compile_html(self, source, dest, is_two_file=True):
         if flag is None:
@@ -59,28 +56,27 @@ class CompileIPynb(PageCompiler):
         HTMLExporter.default_template = 'basic'
         c = Config(self.site.config['IPYNB_CONFIG'])
         exportHtml = HTMLExporter(config=c)
-        with codecs.open(dest, "w+", "utf8") as out_file:
-            with codecs.open(source, "r", "utf8") as in_file:
+        with io.open(dest, "w+", encoding="utf8") as out_file:
+            with io.open(source, "r", encoding="utf8") as in_file:
                 nb = in_file.read()
                 nb_json = nbformat.reads_json(nb)
             (body, resources) = exportHtml.from_notebook_node(nb_json)
             out_file.write(body)
 
-    def create_post(self, path, onefile=False, is_page=False, **kw):
-        metadata = OrderedDict()
-        metadata.update(self.default_metadata)
-        metadata.update(kw)
-        d_name = os.path.dirname(path)
+    def create_post(self, path, **kw):
+        content = kw.pop('content', None)
+        onefile = kw.pop('onefile', False)
+        # is_page is not needed to create the file
+        kw.pop('is_page', False)
+
         makedirs(os.path.dirname(path))
-        meta_path = os.path.join(d_name, kw['slug'] + ".meta")
-        with codecs.open(meta_path, "wb+", "utf8") as fd:
-            fd.write('\n'.join((metadata['title'], metadata['slug'],
-                                metadata['date'], metadata['tags'],
-                                metadata['link'],
-                                metadata['description'], metadata['type'])))
-        print("Your {0}'s metadata is at: {1}".format('page' if is_page else 'post', meta_path))
-        with codecs.open(path, "wb+", "utf8") as fd:
-            fd.write("""{
+        if onefile:
+            raise Exception('The one-file format is not supported by this compiler.')
+        with io.open(path, "w+", encoding="utf8") as fd:
+            if not content.startswith("Write your"):
+                fd.write(content)
+            else:
+                fd.write("""{
  "metadata": {
   "name": ""
  },
