@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -25,7 +25,7 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 from __future__ import unicode_literals
-import codecs
+import io
 import os
 import re
 
@@ -40,13 +40,8 @@ try:
 except ImportError:
     has_docutils = False
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    OrderedDict = dict  # NOQA
-
 from nikola.plugin_categories import PageCompiler
-from nikola.utils import get_logger, makedirs, req_missing
+from nikola.utils import get_logger, makedirs, req_missing, write_metadata
 
 
 class CompileRest(PageCompiler):
@@ -56,6 +51,19 @@ class CompileRest(PageCompiler):
     demote_headers = True
     logger = None
 
+    def _read_extra_deps(self, post):
+        """Reads contents of .dep file and returns them as a list"""
+        dep_path = post.base_path + '.dep'
+        if os.path.isfile(dep_path):
+            with io.open(dep_path, 'r+', encoding='utf8') as depf:
+                deps = [l.strip() for l in depf.readlines()]
+                return deps
+        return []
+
+    def register_extra_dependencies(self, post):
+        """Adds dependency to post object to check .dep file."""
+        post.add_dependency(lambda: self._read_extra_deps(post), 'fragment')
+
     def compile_html(self, source, dest, is_two_file=True):
         """Compile reSt into HTML."""
 
@@ -63,8 +71,8 @@ class CompileRest(PageCompiler):
             req_missing(['docutils'], 'build this site (compile reStructuredText)')
         makedirs(os.path.dirname(dest))
         error_level = 100
-        with codecs.open(dest, "w+", "utf8") as out_file:
-            with codecs.open(source, "r", "utf8") as in_file:
+        with io.open(dest, "w+", encoding="utf8") as out_file:
+            with io.open(source, "r", encoding="utf8") as in_file:
                 data = in_file.read()
                 add_ln = 0
                 if not is_two_file:
@@ -88,11 +96,11 @@ class CompileRest(PageCompiler):
                         'syntax_highlight': 'short',
                         'math_output': 'mathjax',
                         'template': default_template_path,
-                    }, logger=self.logger, l_source=source, l_add_ln=add_ln)
+                    }, logger=self.logger, source_path=source, l_add_ln=add_ln)
                 out_file.write(output)
             deps_path = dest + '.dep'
             if deps.list:
-                with codecs.open(deps_path, "wb+", "utf8") as deps_file:
+                with io.open(deps_path, "w+", encoding="utf8") as deps_file:
                     deps_file.write('\n'.join(deps.list))
             else:
                 if os.path.isfile(deps_path):
@@ -102,22 +110,26 @@ class CompileRest(PageCompiler):
         else:
             return False
 
-    def create_post(self, path, onefile=False, is_page=False, **kw):
-        metadata = OrderedDict()
+    def create_post(self, path, **kw):
+        content = kw.pop('content', None)
+        onefile = kw.pop('onefile', False)
+        # is_page is not used by create_post as of now.
+        kw.pop('is_page', False)
+        metadata = {}
         metadata.update(self.default_metadata)
         metadata.update(kw)
         makedirs(os.path.dirname(path))
-        with codecs.open(path, "wb+", "utf8") as fd:
+        if not content.endswith('\n'):
+            content += '\n'
+        with io.open(path, "w+", encoding="utf8") as fd:
             if onefile:
-                for k, v in metadata.items():
-                    fd.write('.. {0}: {1}\n'.format(k, v))
-            fd.write("\nWrite your {0} here.".format('page' if is_page else 'post'))
+                fd.write(write_metadata(metadata))
+                fd.write('\n')
+            fd.write(content)
 
     def set_site(self, site):
         for plugin_info in site.plugin_manager.getPluginsOfCategory("RestExtension"):
-            if (plugin_info.name in site.config['DISABLED_PLUGINS']
-                or (plugin_info.name in site.EXTRA_PLUGINS and
-                    plugin_info.name not in site.config['ENABLED_EXTRAS'])):
+            if plugin_info.name in site.config['DISABLED_PLUGINS']:
                 site.plugin_manager.removePluginFromCategory(plugin_info, "RestExtension")
                 continue
 
@@ -215,7 +227,7 @@ def rst2html(source, source_path=None, source_class=docutils.io.StringInput,
              parser=None, parser_name='restructuredtext', writer=None,
              writer_name='html', settings=None, settings_spec=None,
              settings_overrides=None, config_section=None,
-             enable_exit_status=None, logger=None, l_source='', l_add_ln=0):
+             enable_exit_status=None, logger=None, l_add_ln=0):
     """
     Set up & run a `Publisher`, and return a dictionary of document parts.
     Dictionary keys are the names of parts, and values are Unicode strings;
@@ -239,7 +251,7 @@ def rst2html(source, source_path=None, source_class=docutils.io.StringInput,
         # logger    a logger from Nikola
         # source   source filename (docutils gets a string)
         # add_ln   amount of metadata lines (see comment in compile_html above)
-        reader.l_settings = {'logger': logger, 'source': l_source,
+        reader.l_settings = {'logger': logger, 'source': source_path,
                              'add_ln': l_add_ln}
 
     pub = docutils.core.Publisher(reader, parser, writer, settings=settings,
@@ -248,7 +260,8 @@ def rst2html(source, source_path=None, source_class=docutils.io.StringInput,
     pub.set_components(None, parser_name, writer_name)
     pub.process_programmatic_settings(
         settings_spec, settings_overrides, config_section)
-    pub.set_source(source, source_path)
+    pub.set_source(source, None)
+    pub.settings._nikola_source_path = source_path
     pub.set_destination(None, destination_path)
     pub.publish(enable_exit_status=enable_exit_status)
 
