@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -43,11 +43,12 @@ class BuildBundles(LateTask):
     name = "create_bundles"
 
     def set_site(self, site):
-        super(BuildBundles, self).set_site(site)
-        if webassets is None and self.site.config['USE_BUNDLES']:
+        self.logger = utils.get_logger('bundles', site.loghandlers)
+        if webassets is None and site.config['USE_BUNDLES']:
             utils.req_missing(['webassets'], 'USE_BUNDLES', optional=True)
-            utils.LOGGER.warn('Setting USE_BUNDLES to False.')
-            self.site.config['USE_BUNDLES'] = False
+            self.logger.warn('Setting USE_BUNDLES to False.')
+            site.config['USE_BUNDLES'] = False
+        super(BuildBundles, self).set_site(site)
 
     def gen_tasks(self):
         """Bundle assets using WebAssets."""
@@ -65,8 +66,7 @@ class BuildBundles(LateTask):
         def build_bundle(output, inputs):
             out_dir = os.path.join(kw['output_folder'],
                                    os.path.dirname(output))
-            inputs = [i for i in inputs if os.path.isfile(
-                os.path.join(out_dir, i))]
+            inputs = [os.path.relpath(i, out_dir) for i in inputs if os.path.isfile(i)]
             cache_dir = os.path.join(kw['cache_folder'], 'webassets')
             utils.makedirs(cache_dir)
             env = webassets.Environment(out_dir, os.path.dirname(output),
@@ -75,7 +75,12 @@ class BuildBundles(LateTask):
                 bundle = webassets.Bundle(*inputs, output=os.path.basename(output))
                 env.register(output, bundle)
                 # This generates the file
-                env[output].urls()
+                try:
+                    env[output].urls()
+                except Exception as e:
+                    self.logger.error("Failed to build bundles.")
+                    self.logger.exception(e)
+                    self.logger.notice("Try running ``nikola clean`` and building again.")
             else:
                 with open(os.path.join(out_dir, os.path.basename(output)), 'wb+'):
                     pass  # Create empty file
@@ -83,20 +88,32 @@ class BuildBundles(LateTask):
         yield self.group_task()
         if (webassets is not None and self.site.config['USE_BUNDLES'] is not
                 False):
-            for name, files in kw['theme_bundles'].items():
+            for name, _files in kw['theme_bundles'].items():
                 output_path = os.path.join(kw['output_folder'], name)
                 dname = os.path.dirname(name)
-                file_dep = [os.path.join(kw['output_folder'], dname, fname)
+                files = []
+                for fname in _files:
+                    # paths are relative to dirname
+                    files.append(os.path.join(dname, fname))
+                file_dep = [os.path.join(kw['output_folder'], fname)
                             for fname in files if
-                            utils.get_asset_path(fname, self.site.THEMES, self.site.config['FILES_FOLDERS'])]
+                            utils.get_asset_path(fname, self.site.THEMES, self.site.config['FILES_FOLDERS'])
+                            or fname == 'assets/css/code.css']
+                # code.css will be generated by us if it does not exist in
+                # FILES_FOLDERS or theme assets.  It is guaranteed that the
+                # generation will happen before this task.
                 task = {
                     'file_dep': list(file_dep),
-                    'task_dep': ['copy_assets'],
+                    'task_dep': ['copy_assets', 'copy_files'],
                     'basename': str(self.name),
                     'name': str(output_path),
-                    'actions': [(build_bundle, (name, files))],
+                    'actions': [(build_bundle, (name, file_dep))],
                     'targets': [output_path],
-                    'uptodate': [utils.config_changed(kw)],
+                    'uptodate': [
+                        utils.config_changed({
+                            1: kw,
+                            2: file_dep
+                        }, 'nikola.plugins.task.bundles')],
                     'clean': True,
                 }
                 yield utils.apply_filters(task, kw['filters'])
@@ -111,8 +128,12 @@ def get_theme_bundles(themes):
         if os.path.isfile(bundles_path):
             with open(bundles_path) as fd:
                 for line in fd:
-                    name, files = line.split('=')
-                    files = [f.strip() for f in files.split(',')]
-                    bundles[name.strip().replace('/', os.sep)] = files
+                    try:
+                        name, files = line.split('=')
+                        files = [f.strip() for f in files.split(',')]
+                        bundles[name.strip().replace('/', os.sep)] = files
+                    except ValueError:
+                        # for empty lines
+                        pass
                 break
     return bundles
