@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -25,12 +25,21 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 from copy import copy
-import nikola.post
 
 from nikola.plugin_categories import Task
 from nikola import utils
 
 
+def update_deps(post, lang, task):
+    """Updates file dependencies as they might have been updated during compilation.
+
+    This is done for example by the ReST page compiler, which writes its
+    dependencies into a .dep file. This file is read and incorporated when calling
+    post.fragment_deps(), and only available /after/ compiling the fragment.
+    """
+    task.file_dep.update(post.fragment_deps(lang))
+
+
 class RenderPosts(Task):
     """Build HTML fragments from metadata and text."""
 
@@ -43,10 +52,10 @@ class RenderPosts(Task):
             "translations": self.site.config["TRANSLATIONS"],
             "timeline": self.site.timeline,
             "default_lang": self.site.config["DEFAULT_LANG"],
-            "hide_untranslated_posts": self.site.config['HIDE_UNTRANSLATED_POSTS'],
+            "show_untranslated_posts": self.site.config['SHOW_UNTRANSLATED_POSTS'],
+            "demote_headers": self.site.config['DEMOTE_HEADERS'],
         }
 
-        nikola.post.READ_MORE_LINK = self.site.config['READ_MORE_LINK']
         yield self.group_task()
 
         for lang in kw["translations"]:
@@ -59,8 +68,10 @@ class RenderPosts(Task):
                     'name': dest,
                     'file_dep': post.fragment_deps(lang),
                     'targets': [dest],
-                    'actions': [(post.compile, (lang, ))],
+                    'actions': [(post.compile, (lang, )),
+                                (update_deps, (post, lang, )),
+                                ],
                     'clean': True,
-                    'uptodate': [utils.config_changed(deps_dict)],
+                    'uptodate': [utils.config_changed(deps_dict, 'nikola.plugins.task.posts')] + post.fragment_deps_uptodate(lang),
                 }
                 yield task
