@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2014 Roberto Alsina and others.
+# Copyright © 2012-2015 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -122,13 +122,18 @@ class Post(object):
         self.skip_untranslated = not self.config['SHOW_UNTRANSLATED_POSTS']
         self._template_name = template_name
         self.is_two_file = True
+        self.newstylemeta = True
         self.hyphenate = self.config['HYPHENATE']
         self._reading_time = None
         self._remaining_reading_time = None
         self._paragraph_count = None
         self._remaining_paragraph_count = None
+        self._dependency_file_fragment = defaultdict(list)
+        self._dependency_file_page = defaultdict(list)
+        self._dependency_uptodate_fragment = defaultdict(list)
+        self._dependency_uptodate_page = defaultdict(list)
 
-        default_metadata = get_meta(self, self.config['FILE_METADATA_REGEXP'], self.config['UNSLUGIFY_TITLES'])
+        default_metadata, self.newstylemeta = get_meta(self, self.config['FILE_METADATA_REGEXP'], self.config['UNSLUGIFY_TITLES'])
 
         self.meta = Functionary(lambda: None, self.default_lang)
         self.meta[self.default_lang] = default_metadata
@@ -140,7 +145,9 @@ class Post(object):
             if lang != self.default_lang:
                 meta = defaultdict(lambda: '')
                 meta.update(default_metadata)
-                meta.update(get_meta(self, self.config['FILE_METADATA_REGEXP'], self.config['UNSLUGIFY_TITLES'], lang))
+                _meta, _nsm = get_meta(self, self.config['FILE_METADATA_REGEXP'], self.config['UNSLUGIFY_TITLES'], lang)
+                self.newstylemeta = self.newstylemeta and _nsm
+                meta.update(_meta)
                 self.meta[lang] = meta
 
         if not self.is_translation_available(self.default_lang):
@@ -209,6 +216,9 @@ class Post(object):
         # If mathjax is a tag, then enable mathjax rendering support
         self.is_mathjax = 'mathjax' in self.tags
 
+        # Register potential extra dependencies
+        self.compiler.register_extra_dependencies(self)
+
     def __repr__(self):
         return '<Post: {0}>'.format(self.source_path)
 
@@ -313,8 +323,69 @@ class Post(object):
             lang = nikola.utils.LocaleBorg().current_lang
         return self.meta[lang]['description']
 
+    def add_dependency(self, dependency, add='both', lang=None):
+        """Adds a file dependency for tasks using that post.
+
+        The ``dependency`` should be a string specifying a path, or a callable
+        which returns such a string or a list of strings.
+
+        The ``add`` parameter can be 'both', 'fragment' or 'page', to indicate
+        that this dependency shall be used
+         * when rendering the fragment to HTML ('fragment' and 'both'), or
+         * when creating a page with parts of the ``Post`` embedded, which
+           includes the HTML resulting from compiling the fragment ('page' or
+           'both').
+
+        If ``lang`` is not specified, this dependency is added for all languages."""
+        if add not in {'fragment', 'page', 'both'}:
+            raise Exception("Add parameter is '{0}', but must be either 'fragment', 'page', or 'both'.".format(add))
+        if add == 'fragment' or add == 'both':
+            self._dependency_file_fragment[lang].append((type(dependency) != str, dependency))
+        if add == 'page' or add == 'both':
+            self._dependency_file_page[lang].append((type(dependency) != str, dependency))
+
+    def add_dependency_uptodate(self, dependency, is_callable=False, add='both', lang=None):
+        """Adds a dependency for task's ``uptodate`` for tasks using that post.
+
+        This can be for example an ``utils.config_changed`` object, or a list of
+        such objects.
+
+        The ``is_callable`` parameter specifies whether ``dependency`` is a
+        callable which generates an entry or a list of entries for the ``uptodate``
+        list, or whether it is an entry which can directly be added (as a single
+        object or a list of objects).
+
+        The ``add`` parameter can be 'both', 'fragment' or 'page', to indicate
+        that this dependency shall be used
+         * when rendering the fragment to HTML ('fragment' and 'both'), or
+         * when creating a page with parts of the ``Post`` embedded, which
+           includes the HTML resulting from compiling the fragment ('page' or
+           'both').
+
+        If ``lang`` is not specified, this dependency is added for all languages."""
+        if add == 'fragment' or add == 'both':
+            self._dependency_uptodate_fragment[lang].append((is_callable, dependency))
+        if add == 'page' or add == 'both':
+            self._dependency_uptodate_page[lang].append((is_callable, dependency))
+
+    def _get_dependencies(self, deps_list):
+        deps = []
+        for dep in deps_list:
+            if dep[0]:
+                # callable
+                result = dep[1]()
+            else:
+                # can add directly
+                result = dep[1]
+            # if result is a list, add its contents
+            if type(result) == list:
+                deps.extend(result)
+            else:
+                deps.append(result)
+        return deps
+
     def deps(self, lang):
-        """Return a list of dependencies to build this post's page."""
+        """Return a list of file dependencies to build this post's page."""
         deps = []
         if self.default_lang in self.translated_to:
             deps.append(self.base_path)
@@ -324,6 +395,18 @@ class Post(object):
             cand_2 = get_translation_candidate(self.config, self.base_path, lang)
             if os.path.exists(cand_1):
                 deps.extend([cand_1, cand_2])
+        deps += self._get_dependencies(self._dependency_file_page[lang])
+        deps += self._get_dependencies(self._dependency_file_page[None])
+        return deps
+
+    def deps_uptodate(self, lang):
+        """Return a list of uptodate dependencies to build this post's page.
+
+        These dependencies should be included in ``uptodate`` for the task
+        which generates the page."""
+        deps = []
+        deps += self._get_dependencies(self._dependency_uptodate_page[lang])
+        deps += self._get_dependencies(self._dependency_uptodate_page[None])
         return deps
 
     def compile(self, lang):
@@ -347,34 +430,40 @@ class Post(object):
             dest,
             self.is_two_file),
         if self.meta('password'):
+            # TODO: get rid of this feature one day (v8?; warning added in v7.3.0.)
+            LOGGER.warn("The post {0} is using the `password` attribute, which may stop working in the future.")
+            LOGGER.warn("Please consider switching to a more secure method of encryption.")
+            LOGGER.warn("More details: https://github.com/getnikola/nikola/issues/1547")
             wrap_encrypt(dest, self.meta('password'))
         if self.publish_later:
             LOGGER.notice('{0} is scheduled to be published in the future ({1})'.format(
                 self.source_path, self.date))
 
-    def extra_deps(self):
-        """get extra depepencies from .dep files
-        This file is created by ReST
-        """
-        dep_path = self.base_path + '.dep'
-        if os.path.isfile(dep_path):
-            with io.open(dep_path, 'r+', encoding='utf8') as depf:
-                return [l.strip() for l in depf.readlines()]
-        return []
-
     def fragment_deps(self, lang):
-        """Return a list of dependencies to build this post's fragment."""
+        """Return a list of uptodate dependencies to build this post's fragment.
+
+        These dependencies should be included in ``uptodate`` for the task
+        which generates the fragment."""
         deps = []
         if self.default_lang in self.translated_to:
             deps.append(self.source_path)
         if os.path.isfile(self.metadata_path):
             deps.append(self.metadata_path)
-        deps.extend(self.extra_deps())
         lang_deps = []
         if lang != self.default_lang:
             lang_deps = [get_translation_candidate(self.config, d, lang) for d in deps]
             deps += lang_deps
-        return [d for d in deps if os.path.exists(d)]
+        deps = [d for d in deps if os.path.exists(d)]
+        deps += self._get_dependencies(self._dependency_file_fragment[lang])
+        deps += self._get_dependencies(self._dependency_file_fragment[None])
+        return deps
+
+    def fragment_deps_uptodate(self, lang):
+        """Return a list of file dependencies to build this post's fragment."""
+        deps = []
+        deps += self._get_dependencies(self._dependency_uptodate_fragment[lang])
+        deps += self._get_dependencies(self._dependency_uptodate_fragment[None])
+        return deps
 
     def is_translation_available(self, lang):
         """Return true if the translation actually exists."""
@@ -408,7 +497,8 @@ class Post(object):
         else:
             return get_translation_candidate(self.config, self.base_path, sorted(self.translated_to)[0])
 
-    def text(self, lang=None, teaser_only=False, strip_html=False, show_read_more_link=True, rss_read_more_link=False):
+    def text(self, lang=None, teaser_only=False, strip_html=False, show_read_more_link=True,
+             rss_read_more_link=False, rss_links_append_query=None):
         """Read the post file for that language and return its contents.
 
         teaser_only=True breaks at the teaser marker and returns only the teaser.
@@ -458,7 +548,7 @@ class Post(object):
                     else:
                         l = self.config['RSS_READ_MORE_LINK'](lang) if rss_read_more_link else self.config['INDEX_READ_MORE_LINK'](lang)
                         teaser += l.format(
-                            link=self.permalink(lang),
+                            link=self.permalink(lang, query=rss_links_append_query),
                             read_more=self.messages[lang]["Read more"],
                             min_remaining_read=self.messages[lang]["%d min remaining to read"] % (self.remaining_reading_time),
                             reading_time=self.reading_time,
@@ -574,9 +664,11 @@ class Post(object):
                                 self.folder, self.meta[lang]['slug'] + extension)
         if sep != os.sep:
             path = path.replace(os.sep, sep)
+        if path.startswith('./'):
+            path = path[2:]
         return path
 
-    def permalink(self, lang=None, absolute=False, extension='.html'):
+    def permalink(self, lang=None, absolute=False, extension='.html', query=None):
         if lang is None:
             lang = nikola.utils.LocaleBorg().current_lang
 
@@ -596,9 +688,10 @@ class Post(object):
             link = urljoin(self.base_url, link[1:])
         index_len = len(self.index_file)
         if self.strip_indexes and link[-(1 + index_len):] == '/' + self.index_file:
-            return link[:-index_len]
-        else:
-            return link
+            link = link[:-index_len]
+        if query:
+            link = link + "?" + query
+        return link
 
     @property
     def previewimage(self, lang=None):
@@ -610,7 +703,9 @@ class Post(object):
         if not image_path:
             return None
 
-        return urljoin(self.base_url, image_path)
+        # This is further parsed by the template, because we don’t have access
+        # to the URL replacer here.  (Issue #1473)
+        return image_path
 
     def source_ext(self, prefix=False):
         """
@@ -691,6 +786,8 @@ def _get_metadata_from_file(meta_data):
     >>> g = _get_metadata_from_file
     >>> list(g([]).values())
     []
+    >>> str(g(["======","FooBar","======"])["title"])
+    'FooBar'
     >>> str(g(["FooBar","======"])["title"])
     'FooBar'
     >>> str(g(["#FooBar"])["title"])
@@ -725,6 +822,10 @@ def _get_metadata_from_file(meta_data):
         if 'title' not in meta:
             if re_rst_title.findall(line) and i > 0:
                 meta['title'] = meta_data[i - 1].strip()
+        if 'title' not in meta:
+            if (re_rst_title.findall(line) and i >= 0 and
+                    re_rst_title.findall(meta_data[i + 2])):
+                meta['title'] = meta_data[i + 1].strip()
         if 'title' not in meta:
             if re_md_title.findall(line):
                 meta['title'] = re_md_title.findall(line)[0]
@@ -758,7 +859,7 @@ def get_metadata_from_meta_file(path, config=None, lang=None):
         if newstylemeta:
             # New-style metadata is basically the same as reading metadata from
             # a 1-file post.
-            return get_metadata_from_file(path, config, lang)
+            return get_metadata_from_file(path, config, lang), newstylemeta
         else:
             while len(meta_data) < 7:
                 meta_data.append("")
@@ -782,7 +883,7 @@ def get_metadata_from_meta_file(path, config=None, lang=None):
             if _type:
                 meta['type'] = _type
 
-            return meta
+            return meta, newstylemeta
 
     elif lang:
         # Metadata file doesn't exist, but not default language,
@@ -790,7 +891,7 @@ def get_metadata_from_meta_file(path, config=None, lang=None):
         # This makes the 2-file format detection more reliable (Issue #525)
         return get_metadata_from_meta_file(path, config, lang=None)
     else:
-        return {}
+        return {}, True
 
 
 def get_meta(post, file_metadata_regexp=None, unslugify_titles=False, lang=None):
@@ -804,15 +905,18 @@ def get_meta(post, file_metadata_regexp=None, unslugify_titles=False, lang=None)
     """
     meta = defaultdict(lambda: '')
 
+    newstylemeta = True
+
     try:
         config = post.config
     except AttributeError:
         config = None
 
-    meta.update(get_metadata_from_meta_file(post.metadata_path, config, lang))
+    _, newstylemeta = get_metadata_from_meta_file(post.metadata_path, config, lang)
+    meta.update(_)
 
     if meta:
-        return meta
+        return meta, newstylemeta
     post.is_two_file = False
 
     if file_metadata_regexp is not None:
@@ -835,7 +939,7 @@ def get_meta(post, file_metadata_regexp=None, unslugify_titles=False, lang=None)
             meta['title'] = os.path.splitext(
                 os.path.basename(post.source_path))[0]
 
-    return meta
+    return meta, newstylemeta
 
 
 def hyphenate(dom, lang):
