@@ -1,11 +1,8 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals, absolute_import
 
-# This code is so you can run the samples without installing the package,
-# and should be before any import touching nikola, in any file under tests/
 import os
 import sys
-sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
 
 
 import unittest
@@ -28,29 +25,6 @@ class BasicCommandImportWordpress(BaseTestCase):
         del self.import_filename
 
 
-class TestXMLGlueing(BasicCommandImportWordpress):
-    def test_making_correct_newlines(self):
-        xml = [b"Some information about how to (un)subscripe to a google group with a normal mail client.\n",
-               b"<ul>\n",
-               b"    <li>to post: <strong>groupname@googlegroups.com</strong></li>\n",
-               b"    <li>to <em>subscribe</em>: <strong>groupname+subscribe@googlegroups.com</strong></li>\n",
-               b"    <li>to <em>unsubscribe</em>: <strong>groupname+unsubscribe@googlegroups.com</strong></li>\n",
-               b"</ul>\n",
-               b"Easy.\n"]
-
-        expected_xml = b"""Some information about how to (un)subscripe to a google group with a normal mail client.
-
-<ul>
-    <li>to post: <strong>groupname@googlegroups.com</strong></li>
-    <li>to <em>subscribe</em>: <strong>groupname+subscribe@googlegroups.com</strong></li>
-    <li>to <em>unsubscribe</em>: <strong>groupname+unsubscribe@googlegroups.com</strong></li>
-</ul>
-
-Easy.
-"""
-        self.assertEqual(expected_xml, self.import_command._glue_xml_lines(xml))
-
-
 class TestQTranslateContentSeparation(BasicCommandImportWordpress):
 
     def test_conserves_qtranslate_less_post(self):
@@ -216,6 +190,7 @@ class CommandImportWordpressTest(BasicCommandImportWordpress):
             self.import_filename)
         self.import_command.context = self.import_command.populate_context(
             channel)
+        self.import_command.base_dir = ''
         self.import_command.output_folder = 'new_site'
         self.import_command.squash_newlines = True
         self.import_command.no_downloads = False
@@ -268,17 +243,25 @@ The end.
         write_content.assert_any_call(
             'new_site/posts/2008/07/arzt-und-pfusch-s-i-c-k.wp'.replace('/', os.sep),
             '''<img class="size-full wp-image-10 alignright" title="Arzt+Pfusch - S.I.C.K." src="http://some.blog/wp-content/uploads/2008/07/arzt_und_pfusch-sick-cover.png" alt="Arzt+Pfusch - S.I.C.K." width="210" height="209" />Arzt+Pfusch - S.I.C.K.Gerade bin ich \xfcber das Album <em>S.I.C.K</em> von <a title="Arzt+Pfusch" href="http://www.arztpfusch.com/" target="_blank">Arzt+Pfusch</a> gestolpert, welches Arzt+Pfusch zum Download f\xfcr lau anbieten. Das Album steht unter einer Creative Commons <a href="http://creativecommons.org/licenses/by-nc-nd/3.0/de/">BY-NC-ND</a>-Lizenz.
+
 Die Ladung <em>noisebmstupidevildustrial</em> gibts als MP3s mit <a href="http://www.archive.org/download/dmp005/dmp005_64kb_mp3.zip">64kbps</a> und <a href="http://www.archive.org/download/dmp005/dmp005_vbr_mp3.zip">VBR</a>, als Ogg Vorbis und als FLAC (letztere <a href="http://www.archive.org/details/dmp005">hier</a>). <a href="http://www.archive.org/download/dmp005/dmp005-artwork.zip">Artwork</a> und <a href="http://www.archive.org/download/dmp005/dmp005-lyrics.txt">Lyrics</a> gibts nochmal einzeln zum Download.''')
         write_content.assert_any_call(
             'new_site/stories/kontakt.wp'.replace('/', os.sep), """<h1>Datenschutz</h1>
+
 Ich erhebe und speichere automatisch in meine Server Log Files Informationen, die dein Browser an mich \xfcbermittelt. Dies sind:
 
 <ul>
+
     <li>Browsertyp und -version</li>
+
     <li>verwendetes Betriebssystem</li>
+
     <li>Referrer URL (die zuvor besuchte Seite)</li>
+
     <li>IP Adresse des zugreifenden Rechners</li>
+
     <li>Uhrzeit der Serveranfrage.</li>
+
 </ul>
 
 Diese Daten sind f\xfcr mich nicht bestimmten Personen zuordenbar. Eine Zusammenf\xfchrung dieser Daten mit anderen Datenquellen wird nicht vorgenommen, die Daten werden einzig zu statistischen Zwecken erhoben.""")
@@ -469,5 +452,6 @@ You can use the <a title="Jenkins Plugin: Violations" href="https://wiki.jenkins
         self.assertEqual(1, len(redirections))
         self.assertTrue(('somewhere/else/index.html', '/posts/somewhereelse.html') in redirections)
 
+
 if __name__ == '__main__':
     unittest.main()
